% Compute the element load vectors corresponding to nonzero
% essential boundary conditions (prescribed temperature rate).
% Return an array of them so they may be assembled.
%    Call as
% evs = nz_ebc_loads(feb, geom, temp_rate)
%     geom=geometry field
%     temp=temperature rate field
%
function evs = nz_ebc_loads_capacity (self, geom, temp_rate)
    gcells = get(self.feblock,'gcells');
    ngcells = length(gcells);
    nfens = get(gcells(1),'nfens');
    dim = get(geom,'dim');
    % Pre-allocate the element matrices
    evs(1:ngcells) = deal(elevec);
    % Integration rule
    integration_rule = get(self.feblock, 'integration_rule');
    pc = get(integration_rule, 'param_coords');
    w  = get(integration_rule, 'weights');
    npts_per_gcell = get(integration_rule, 'npts');
    % Material
    mat = get(self.feblock, 'mater');
    cv = get(mat,'specific_heat');
    % Now loop over all gcells in the block
    for i=1:ngcells
        conn = get(gcells(i), 'conn'); % connectivity
        pT = gather(temp_rate, conn, 'prescribed_values');
        if norm (pT) ~= 0
            x = gather(geom, conn, 'values', 'noreshape'); 
            Ce = zeros(nfens); % element matrix
            % Loop over all integration points
            for j=1:npts_per_gcell
                N = Nmat(gcells(i), pc(j,:));
                Nder = Ndermat_param (gcells(i), pc(j,:));
                [Nspder,detJ]=Ndermat_spatial(gcells(i),Nder,x);
                Ce = Ce + cv*N*N' * detJ * w(j);
            end
            evs(i) = set(evs(i), 'vec', -Ce*pT);
            evs(i) = set(evs(i), 'eqnums', ...
                gather(temp_rate, conn, 'eqnums'));
        end
    end
    return;
end
