% Compute the linear, displacement independent, strain-displacement matrix
% for a three-dimensional manifold element with nfens nodes.
%   Call as:
%      B = Blmat3(g, Ndersp, es)
%   where
%      self=gcell
%      Ndersp=matrix of spatial derivatives of the basis functions.
%         Derivative of basis function i is in the ith row.
%      es=orthogonal matrix with the unit basis vectors of the local
%         coordinate system as columns.
%         size(es)= [ndim,ndim], where ndim = Number of spatial dimensions of
%         the embedding space.
%
function B = Blmat3(self, Ndersp, es)
    nfens = size(Ndersp, 1);
    dim=3;
    for i= 1:nfens
        B(:,dim*(i-1)+1:dim*i)
        = [ Ndersp(i,1) 0           0  ; ...
            0           Ndersp(i,2) 0  ; ...
            0           0           Ndersp(i,3) ; ...
            Ndersp(i,2) Ndersp(i,1) 0  ; ...
            Ndersp(i,3) 0           Ndersp(i,1) ; ...
            0           Ndersp(i,3) Ndersp(i,2) ]*es(:,1:3)';
    end
    return;
end

