% Evaluate the Jacobian.
%   Call as:
%      detJ = Jacobian(self, tangents)
%   where
%      self=gcell,
%      tangents = matrix with the tangents to the parametric coordinates in
%           the columns; depending on the dimensionality of the geometric
%           cell, that will be 1, 2, or 3 columns.
%
function detJ = Jacobian(self, tangents)
    [sdim, ntan] = size(tangents);
    if     ntan==1 % 1-D gcell
        detJ = norm(tangents);
    elseif ntan==2 % 2-D gcell
        if sdim==ntan
            detJ = det(tangents);% Compute the Jacobian
        else
            detJ = norm(skewmat(tangents(1))*tangents(2));
        end
    else
        detJ = det(tangents);% Compute the Jacobian
    end
end
