% Constructor
% class represents a one-dimensional manifold geometric cell, which encloses some part
% of the computational domain.
% This class is abstract, i.e. every usable 1-D gcell has to be
% derived from it.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: same as gcell.
% and area = cross-sectional area of the rod (default is 1.0)
%   Example: gcell_1_manifold(struct ('id',13,'conn',[21 3], 'area',4.5))  creates a cell
%      that connects nodes 21 3, hands cross-sectional area of 4.5 units, and gives it the `name' 13.
%
function retobj = gcell_1_manifold (varargin)
    class_name='gcell_1_manifold';
    if (nargin == 0)
        self.area= 1.0;
        parent=gcell(options);
        retobj = class(self,class_name, parent);
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options=varargin{1}; 
            self.area = 1.0;
            if isfield(options,'area')
                self.area = options.area;
            end
            parent=gcell(options);
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end