% Constructor
% Class represents a two-manifold geometric cell, which encloses some part
% of the computational domain.
% This class is abstract, i.e. every usable gcell has to be
% derived from it.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: same as gcell.
% and thickness = thickness of the element
%
%   Example: gcell_2_manifold(struct ('id',13,'conn',[1 8 4], 'thickness',0.2))  creates a cell
%      that connects nodes 1 8 4, and gives it the `name' 13.
%
function retobj = gcell_2_manifold (varargin)
    class_name='gcell_2_manifold';
    nfens=3;
    if (nargin == 0)
        options=varargin{1};
        self.thickness = 1.0;
        parent=gcell(options);
        retobj = class(self,class_name, parent);
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options=varargin{1};
            self.thickness = 1.0;
            if isfield(options,'thickness')
                self.thickness = options.thickness;
            end
            parent=gcell(options);
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end