% Constructor
% Class represents a three-node triangle geometric cell, which encloses some part
% of the computational domain.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: same as gcell.
% and thickness = thickness of the element
%
%   Example: gcell_T3(struct ('id',13,'conn',[1 8 4], 'thickness',0.2))  creates a cell
%      that connects nodes 1 8 4, and gives it the `name' 13.
%
function retobj = gcell_T3 (varargin)
    class_name='gcell_T3';
    nfens=3;
    if (nargin == 0)
        options=varargin{1}; options.nfens=nfens;
        parent=gcell_2_manifold(options);
        retobj = class(struct([]),class_name, parent);
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options=varargin{1}; options.nfens=nfens;
            parent=gcell_2_manifold(options);
            retobj = class(struct([]),class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end